--!NEEDS:ui/uipanel.lua
--require "lfs"

local Button=UI.Factory.new(
	{ class="UI.Panel", Alpha=0, layoutModel={}, 
		Border={class=UI.Border.Basic, params={ radius=3, bgColor=0x8080FF, bgAlpha=1}},
		name="tfConnect", 
		children={
			{ class="UI.Label", layout={}, name="tfLabel" }
		}
	},
	function (b,d) 
		b.tfLabel:setText(d.Text)
	end
)

UI.FileSelector=Core.class(UI.Panel,function() end)
function UI.FileSelector:init()
	self.root=self
	local rootNodes={}
	for k,v in ipairs(lfs.drives()) do
		rootNodes[k]={ name=v }
	end
	UI.Builder({
		class="UI.Panel", Color=0xc0c0c0, Alpha=0, 
		Border=UI.Border.Basic.new{ thickness=3, radius=10, bgColor=0xc0c0c0,bgAlpha=1,fgColor=0x000000,fgAlpha=1 },
		name="root",
		layoutModel=UI.Layout.Vertical,
		children={
			{ class="UI.Label", Text="Pick a file:" },
			{ class="UI.Panel", Alpha=0, layoutModel=UI.Layout.Horizontal, layout={weighty=1,weightx=1,insetBottom=2},
				children={
					--Directory Tree
					{ class=UI.Viewport, layout={weightx=1,fill=1},
						Content={ class="UI.Tree", name="dirTree", layout={anchor=Sprite.LAYOUT_ANCHOR_NORTHWEST}, dataMapper=function(item) return self:dirMapper(item) end, data=rootNodes },
					},
					--File list
					{ class=UI.Viewport,  layout={weightx=3,fill=1},
						Content={ class="UI.Table", name="fileTable", layout={anchor=Sprite.LAYOUT_ANCHOR_NORTHWEST} },
					},
				}
			},
			{ class="UI.Panel", Alpha=0, layoutModel=UI.Layout.Horizontal,
				children={
					{ class="UI.Label", Text="File:" },
					{ class="UI.TextField", name="tfLogin", Text="", layout={ weightx=1} },
					{ factory=Button, name="btOK", Text="OK" },
					{ factory=Button, name="btCancel", Text="Cancel" },
				},
			}
		}
	},self,self)
end

require "json"

function UI.FileSelector:dirMapper(dir)
	if dir.files==nil then
		dir.files={}
		dir.dirs={}
		local path=dir.path or dir.name
		for file in lfs.dir(path) do
			if not (file=="." or file=="..") then
				local lpath=path..file
				local lmode=lfs.attributes(lpath,"mode")
				if lmode == "file" then 
					table.insert(dir.files,file)
				elseif lmode=="directory" then 
					table.insert(dir.dirs,{ name=file, path=lpath.."\\" })
				end
			end
		end
	end
	return dir.name,function() return dir.dirs end
end
